@@ -134,7 +134,7 @@ ggplot_dendogram <- function(dendro,factor_for_color){
 
 #-------------------------------------------------------------------------
 
-extract_results_for_one_comp = function(dds,Factor,A,B, thresholds){
+extract_results_for_one_comp = function(dds,Factor,A,B, thresholds, correct_by_fdrtool){
   if (Factor!="Interaction"){
     res = results(dds, contrast = c(Factor,A,B) , cooksCutoff=FALSE, independentFiltering=FALSE)
   }else{
@@ -148,26 +148,29 @@ extract_results_for_one_comp = function(dds,Factor,A,B, thresholds){
   res <- res[!is.na(res$pvalue),]
   padj_corrected = FALSE
   res_bak <- cbind(res)#deep copy of res
+  if (correct_by_fdrtool) {
 
-  q1 = res$pvalue <= 0.25 #TRUE/FALSE vector
-  q234 = res[res$pvalue > 0.25,]
-  t1ofq234 = q234$pvalue > 0.25 & q234$pvalue <= 0.5 #TRUE/FALSE vector
-  t2ofq234 = q234$pvalue > 0.5 & q234$pvalue <= 0.75 #TRUE/FALSE vector
-  t3ofq234 = q234$pvalue > 0.75 & q234$pvalue <= 1 #TRUE/FALSE vector
+    q1 = res$pvalue <= 0.25 #TRUE/FALSE vector
+    q234 = res[res$pvalue > 0.25,]
+    t1ofq234 = q234$pvalue > 0.25 & q234$pvalue <= 0.5 #TRUE/FALSE vector
+    t2ofq234 = q234$pvalue > 0.5 & q234$pvalue <= 0.75 #TRUE/FALSE vector
+    t3ofq234 = q234$pvalue > 0.75 & q234$pvalue <= 1 #TRUE/FALSE vector
 
-  # if (mean(res$pvalue > 0.9) > 0.1) {
-  if(mean(q1) < 0.2 || mean(t1ofq234) > 0.38 || mean(t1ofq234) < 0.28 || mean(t2ofq234) > 0.38 || mean(t2ofq234) < 0.28 || mean(t3ofq234) > 0.38 || mean(t3ofq234) < 0.28) {
-    padj_corrected<-tryCatch({
-      res.na.padj <- res[is.na(res$padj),]
-      res <- res[!is.na(res$padj),] #fdrtool don't work on NA values
-      res <- res[,-which(names(res) == "padj")]
-      FDR.res <- fdrtool(res$stat, statistic = "normal", plot = F, verbose = F)
-      res[, "padj"]  <- p.adjust(FDR.res$pval, method = "BH")
-      res <- rbind(res, res.na.padj)
-      padj_corrected = TRUE
-    }, error = function(err) {
-      return('Failed')
-    }) # END tryCatch
+    # if (mean(res$pvalue > 0.9) > 0.1) {
+    if(mean(q1) < 0.2 || mean(t1ofq234) > 0.38 || mean(t1ofq234) < 0.28 || mean(t2ofq234) > 0.38 || mean(t2ofq234) < 0.28 || mean(t3ofq234) > 0.38 || mean(t3ofq234) < 0.28) {
+      padj_corrected<-tryCatch({
+        res.na.padj <- res[is.na(res$padj),]
+        res <- res[!is.na(res$padj),] #fdrtool don't work on NA values
+        # res <- res[,-which(names(res) == "padj")]
+        colnames(res)[which(names(res) == "padj")] <- "padj.before-fdr-correction" # change the name of the original padj.
+        FDR.res <- fdrtool(res$stat, statistic = "normal", plot = F, verbose = F)
+        res[, "padj"]  <- p.adjust(FDR.res$pval, method = "BH") # all downstream anlysis will be done on padj after fdr correction
+        res <- rbind(res, res.na.padj)
+        padj_corrected = TRUE
+      }, error = function(err) {
+        return('Failed')
+      }) # END tryCatch
+    }
   }
   if (padj_corrected == 'Failed') {
     res <- res_bak
