@@ -72,7 +72,7 @@ class StepReport(object):
     def get_step_path(self, file):
         template_step = os.path.basename(os.path.dirname(file))
         for step_path in os.listdir(os.path.dirname(os.path.dirname(file))):
-            if template_step[2:] in step_path:
+            if os.path.isdir(step_path) and template_step[2:] in step_path:
                 return os.path.join(os.path.dirname(os.path.dirname(file)), step_path, os.path.basename(file))
         return ''
 
@@ -256,7 +256,7 @@ class NGSplotConfig(object):
 
     def get_step_path(self, step):
         for step_path in os.listdir(self.root_dir):
-            if step[2:] in step_path:
+            if os.path.isdir(step_path) and step[2:] in step_path:
                 return os.path.join(self.root_dir, step_path)
         return ''
 
